@@ -12,5 +12,13 @@ fn main() -> Result<(), std::io::Error> {
         .build_client(true)
         .build_server(false)
         .format(true)
+        .type_attribute(
+            "TransactionErrorType",
+            "#[cfg_attr(test, derive(enum_iterator::IntoEnumIterator))]",
+        )
+        .type_attribute(
+            "InstructionErrorType",
+            "#[cfg_attr(test, derive(enum_iterator::IntoEnumIterator))]",
+        )
         .compile(&protos, &[proto_base_path])
 }
